package com.simonstl.fragment;
import org.xml.sax.helpers.AttributesImpl;
import org.xml.sax.*;
import org.xml.sax.helpers.AttributesImpl;
import org.xml.sax.helpers.DefaultHandler;
import org.xml.sax.XMLFilter;
import org.xml.sax.helpers.XMLFilterImpl;

/*
The contents of this file are subject to the Mozilla Public License  Version 1.1 (the "License"); you may not use this file except in  compliance with the License. You may obtain a copy of the License at 
http://www.mozilla.org/MPL/ 
Software distributed under the License is distributed on an "AS IS"  basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See the  License for the specific language governing rights and limitations under  the License. 

The Original Code is available at  http://simonstl.com/projects/fragment/original. 

The Initial Developer of the Original Code is Simon St.Laurent. Portions  created by Simon St.Laurent are Copyright (C) 2001. All Rights Reserved. 

Contributor(s): 
*/

/**
* <p>The Element class stores information about elements (and perhaps someday attributes)
* in a format that supports namespaces, allows the preservation of prefix information,
* and supports matching on namespace URIs and localNames.</p>
*
* <p>I may eventually add support for attributes, and also for wildcard matching on nsURI
* and/or localName.</p>
*
* <p>Version 0.03 added properties for content and attributes.  It also added the eventElement()
* method, which allows Element objects to write out their own SAX events.  This should make
* it easier to manage configuration in the future.</p>
*
* <p>version 0.02 added the getKey() method, so that Elements could define their own keys.
* This should permit future versions to support more complex matching than just nsURI>localName.
* (Making that work will involve revisions to matchElement (String match) as well.)</p>
*
* @version 0.02 24 June 2001
* @author Simon St.Laurent
*/

public class Element {
    public String nsURI;
    public String localName;
    public String prefix;
    public AttributesImpl atts=null;
    public String content=null;

public Element (String newNsURI, String newLocalName) {
    nsURI=newNsURI;
    localName=newLocalName;
    prefix="";
}

public Element (String newNsURI, String newLocalName, String newPrefix) {
    nsURI=newNsURI;
    localName=newLocalName;
    prefix=newPrefix;
}

public Element (String newNsURI, String newLocalName, String newPrefix, String newContent) {
    nsURI=newNsURI;
    localName=newLocalName;
    prefix=newPrefix;
    content=newContent;
}

public Element (Element oldElement) {
    nsURI=new String (oldElement.nsURI);
    localName=new String (oldElement.localName);
    prefix=new String (oldElement.prefix);
}


public boolean matchElement (String match) {
    return (match.equals(nsURI+">"+localName));
}

public String getKey() {
    return nsURI+">"+localName;
}

public void setAtts(AttributesImpl newAtts) {
      atts=newAtts;
}

public AttributesImpl getAtts() {
      return atts;
}

public void setContent(String newContent) {
      content=newContent;
}

public String getContent() {
      return content;
}

public void eventElement(XMLFilterImpl handler) throws SAXException {
      String QName;

      if (atts==null) {
        atts=new AttributesImpl();
      }

       if (!(prefix.equals(""))) {
        QName=prefix+":"+localName;
       } else {
        QName=localName;
       }
//System.out.println("starting element " + QName);
      if (!(( nsURI.equals("") ) && ( localName.equals("") ) && ( QName.equals("") ))) {
        handler.startElement(nsURI, localName, QName, atts);
      } 
//System.out.println("starting content " + content);

      if (!(content.equals(""))) {
        handler.characters(content.toCharArray(), 0, content.length());
      }
//System.out.println("ending element " + QName);

      if (!(( nsURI.equals("") ) && ( localName.equals("") ) && ( QName.equals("") ))) {
        handler.endElement(nsURI, localName, QName);
      }
}


public void print() {
System.out.println("result: "+prefix+"("+nsURI+"):"+localName);
}

public String toString() {
   return (prefix+"("+nsURI+"):"+localName);
}

}